@@ -21,25 +21,19 @@ knitr::opts_knit$set(warning = F, message = F,  default_opts = T)
 
 ## ----echo=FALSE----------------------------------------------------------
 tryCatch({
-  current_sha <- paste0("@", httr::content(
-    httr::GET("https://api.github.com/repos/boennecd/dynamichazard/git/refs/heads/master")
-    )$object$sha)
+  current_sha <- system("git rev-parse --short HEAD", intern = TRUE)
+  if(grepl("^fatal: Not a git repository", current_sha))
+    current_sha <- ""
 }, error = function(...){ current_sha <<- "" })
 
-stopifnot(length(current_sha) > 0 && class(current_sha) == "character")
-
-current_version <- paste0("boennecd/dynamichazard", current_sha)
-
-## ------------------------------------------------------------------------
-current_version # the string you need to pass to devtools::install_github
-
-## ----eval=FALSE----------------------------------------------------------
-#  devtools::install_github(current_version)
+current_version <- paste0(
+  "boennecd/dynamichazard", if(nchar(current_sha) > 0) "@" else "",
+  current_sha)
 
 ## ----eval=FALSE----------------------------------------------------------
 #  install.packages("dynamichazard")
 
-## ---- echo=FALSE---------------------------------------------------------
+## ----echo=FALSE----------------------------------------------------------
 library(survival)
 source("../R/sims.R")
 
@@ -48,9 +42,9 @@ start_fun <- function(t_0 = t_0, t_max = t_max) max(0, runif(1, t_0 - t_max, t_m
 # set.seed(print(round(runif(1, max = 1e6))))
 set.seed(126265)
 simple_ex <- test_sim_func_logit(
-    n_series = 2e3, 
+    n_series = 2e3,
     beta_start = c(1.5, -1),
-    intercept_start = - 3, 
+    intercept_start = - 3,
     sds = rep(.5, 3),
     t_max = 28,
     n_vars = 2,
@@ -60,58 +54,59 @@ simple_ex <- test_sim_func_logit(
     tstart_sampl_func = start_fun)$res
 # sum(simple_ex$event)
 
-stopifnot(any(simple_ex$event[simple_ex$id == 1] == 1) && 
+stopifnot(any(simple_ex$event[simple_ex$id == 1] == 1) &&
               all(simple_ex$event[simple_ex$id == 2] == 0))
 
-## ---- echo = FALSE-------------------------------------------------------
-knitr::kable(head(simple_ex, 10), digits = 4)
+## ----echo = FALSE, results='asis'----------------------------------------
+knitr::kable(
+  head(simple_ex, 10), digits = 4, format = "latex",
+  booktabs = T, row.names = FALSE, align = rep("r", 6))
 
 ## ------------------------------------------------------------------------
 library(dynamichazard)
-library(survival)
 dd_fit_short <- ddhazard(
-  Surv(tstart, tstop, event) ~ x1 + x2, # Formula like for coxph from survival
-       data = simple_ex,
-       by = 1,                          # Length of time intervals
-       Q = diag(0.1, 3),                # Covariance matrix in state eqn 
-       Q_0 = diag(10000, 3),            # Covariance matrix for initial state
-                                        # vector
-       max_T = 28,                      # Last time we observe
-       id = simple_ex$id                # id of individuals
-  )                      
+  Surv(time, status == 2) ~ log(bili), # Formula like for coxph from survival
+  data = pbc,
+  by = 100,                            # Length of time intervals
+  Q = diag(.3^2, 2),                   # Covariance matrix in state eqn
+  Q_0 = diag(2^2, 2),                  # Covariance matrix for initial state
+                                       # vector
+  max_T = 3600,                        # Last time we observe
+  id = pbc$id,                         # id of individuals
+  control = ddhazard_control(eps = 1e-4))
 
 # Print diagonal of covariance matrix
-diag(dd_fit_short$Q) 
+diag(dd_fit_short$Q)
 
 ## ------------------------------------------------------------------------
 library(dynamichazard)
-library(survival)
 dd_fit_wide <- ddhazard(
-  Surv(tstart, tstop, event) ~ x1 + x2, 
-       data = simple_ex,
-       by = 2,                          # increased
-       Q = diag(0.1, 3),               
-       Q_0 = diag(10000, 3), 
-       max_T = 28,                      
-       id = simple_ex$id)            
+  Surv(time, status == 2) ~ log(bili),
+  data = pbc,
+  by = 150,                       # Increased
+  Q = diag(.3^2, 2),
+  Q_0 = diag(2^2, 2),
+  max_T = 3600,
+  id = pbc$id,
+  control = ddhazard_control(eps = 1e-4))
 
 # Print relative differences between diagonal of covariance matrices
-Q_short <- dd_fit_short$Q
-Q_wide <- dd_fit_wide$Q
-diag((Q_wide - Q_short) / Q_short)   
+Q_short <- sqrt(diag(dd_fit_short$Q))
+Q_wide <- sqrt(diag(dd_fit_wide$Q))
+(Q_wide - Q_short) / Q_short
 
-## ---- fig.height= 5------------------------------------------------------
-par(mfcol = c(2, 2), mar = c(5, 4, 1, 1))
+## ----fig.align='center', fig.height=2.5----------------------------------
+par(mfcol = c(1, 2), mar = c(5, 4, 1, 1), cex = .75)
 
-for(i in 1:3){
+for(i in 1:2){
   plot(dd_fit_short, cov_index = i, col = "Black")
-  plot(dd_fit_wide, cov_index = i, col = "Red", add = T)
+  plot(dd_fit_wide, cov_index = i, col = "DarkBlue", add = T)
 }
 
-## ---- eval=FALSE---------------------------------------------------------
+## ----eval=FALSE----------------------------------------------------------
 #  dynamichazard::ddhazard_app()
 
-## ----binning_fig, echo=FALSE, results="hide", fig.cap = "Illustration of going from event times to binary variables. Each horizontal line represents an individual. A cross indicates that new covariates are observed while a filled circle indicates that the individual have died. Open circles indicates that the individual is right censored. Vertical dashed lines are time interval borders.", fig.height=3----
+## ----binning_fig, echo=FALSE, results="hide", fig.cap = "Illustration of going from event times to binary variables. Each horizontal line represents an individual. A cross indicates that new covariates are observed while a filled circle indicates that the individual have died. Open circles indicates that the individual is right-censored. Vertical dashed lines are time interval borders.", fig.height=3, fig.align="center"----
 par(cex = .8, mar = c(1, 4, 1, 2))
 plot(c(0, 4), c(0, 1), type="n", xlab="", ylab="", axes = F)
 
@@ -137,7 +132,7 @@ x_vals_and_point_codes = list(
   cbind(c(0.1, .6, 2.1, 3.1 + runif(1)),
         c(4, 4, 4, 16)),
   cbind(c(2, 2.33),
-        c(4, 16)), 
+        c(4, 16)),
   cbind(c(0.1, 1.3),
         c(4, 1)))
 
@@ -147,18 +142,18 @@ x_vals_and_point_codes = x_vals_and_point_codes[
 for(i in seq_along(x_vals_and_point_codes)){
   vals = x_vals_and_point_codes[[i]]
   y = y_pos[i]
-  
+
   xs = vals[, 1]
   n_xs = length(xs)
-  
-  # add lines
+
+  # Add lines
   segments(xs[-n_xs], rep(y, n_xs - 1),
            xs[-1], rep(y, n_xs - 1))
-  
+
   # Add point
-  points(xs, rep(y, n_xs), pch = vals[, 2], 
+  points(xs, rep(y, n_xs), pch = vals[, 2],
          cex = ifelse(vals[, 2] == 1, par()$cex * 2.5, par()$cex))
-  
+
   # Add numbers
   text(xs, rep(y + .05, n_xs), as.character(0:(n_xs -1)))
 }
