@@ -22,7 +22,7 @@ public:
   /* log-scale */
   double log_importance_dens;
   double log_weight;
-  double log_unnormalized_weight;
+  double log_likelihood_term;
   double log_resampling_weight;
 
   particle(
